@@ -222,10 +222,12 @@ def delete_deployment(endpoint: str, auth_token: str, deployment_key: str):
 # Executes the start command in a specified deployment.
 # The initiation of a deployment plan will check if it's valid.
 # The applications to redeploy, if applicable, will also be included in the deployment plan.
+# If continue with errors is allowed, an additional parameter is added to the query string.
 def start_deployment(endpoint: str, auth_token: str, deployment_key: str, **kwargs):
     redeploy = False
     if "redeploy_outdated" not in kwargs:
         redeploy = True
+
     # Builds the API call
     query = "{}/{}/{}".format(DEPLOYMENTS_ENDPOINT,
                               deployment_key, DEPLOYMENT_START_ENDPOINT)
@@ -233,6 +235,10 @@ def start_deployment(endpoint: str, auth_token: str, deployment_key: str, **kwar
     if not redeploy:
         query = "{}?RedeployOutdated={}".format(
             query, kwargs["redeploy_outdated"])
+    # If the parameter to continue with errors has a value of True, that must be included in the call
+    if "continue_with_errors" in kwargs and kwargs["continue_with_errors"]:
+        query = "{}&ContinueWithErrors={}".format(query, True)
+
     # Sends the request
     response = send_post_request(endpoint, auth_token, query, None)
     status_code = int(response["http_status"])
@@ -282,6 +288,11 @@ def continue_deployment(endpoint: str, auth_token: str, deployment_key: str):
             "There was an error. Response from server: {}".format(response))
 
 
+# Function to check if the deployment is with Prepared status
+def check_deployment_two_step_deploy_status(dep_status: dict):
+    return dep_status["Info"] == "deployment_prepared"
+
+
 # ---------------------- PRIVATE METHODS ----------------------
 def _create_deployment_plan(artifact_dir: str, endpoint: str, lt_api_version: int, auth_token: str, app_keys: str, dep_note: str, source_env: str, dest_env: str):
     if lt_api_version == 1:
